@@ -1951,6 +1951,44 @@ if ($] >= 5.038 || ! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"wing"} = "\x{1FABD}";
   $hash{"wireless"} = "\x{1F6DC}";
 }
+if ($] >= 5.042 || ! $ENV{SLACKEMOJI_STRICT}) {
+  $hash{"broken_chain"} = "\x{26D3}\x{FE0F}\x{200D}\x{1F4A5}";
+  $hash{"brown_mushroom"} = "\x{1F344}\x{200D}\x{1F7EB}";
+  $hash{"face_with_bags_under_eyes"} = "\x{1FAE9}";
+  $hash{"family_adult_adult_child"} = "\x{1F9D1}\x{200D}\x{1F9D1}\x{200D}\x{1F9D2}";
+  $hash{"family_adult_adult_child_child"} = "\x{1F9D1}\x{200D}\x{1F9D1}\x{200D}\x{1F9D2}\x{200D}\x{1F9D2}";
+  $hash{"family_adult_child"} = "\x{1F9D1}\x{200D}\x{1F9D2}";
+  $hash{"family_adult_child_child"} = "\x{1F9D1}\x{200D}\x{1F9D2}\x{200D}\x{1F9D2}";
+  $hash{"fingerprint"} = "\x{1FAC6}";
+  $hash{"flag-sark"} = "\x{1F1E8}\x{1F1F6}";
+  $hash{"harp"} = "\x{1FA89}";
+  $hash{"head_shaking_horizontally"} = "\x{1F642}\x{200D}\x{2194}\x{FE0F}";
+  $hash{"head_shaking_vertically"} = "\x{1F642}\x{200D}\x{2195}\x{FE0F}";
+  $hash{"leafless_tree"} = "\x{1FABE}";
+  $hash{"lime"} = "\x{1F34B}\x{200D}\x{1F7E9}";
+  $hash{"man_in_manual_wheelchair_facing_right"} = "\x{1F468}\x{200D}\x{1F9BD}\x{200D}\x{27A1}\x{FE0F}";
+  $hash{"man_in_motorized_wheelchair_facing_right"} = "\x{1F468}\x{200D}\x{1F9BC}\x{200D}\x{27A1}\x{FE0F}";
+  $hash{"man_kneeling_facing_right"} = "\x{1F9CE}\x{200D}\x{2642}\x{FE0F}\x{200D}\x{27A1}\x{FE0F}";
+  $hash{"man_running_facing_right"} = "\x{1F3C3}\x{200D}\x{2642}\x{FE0F}\x{200D}\x{27A1}\x{FE0F}";
+  $hash{"man_walking_facing_right"} = "\x{1F6B6}\x{200D}\x{2642}\x{FE0F}\x{200D}\x{27A1}\x{FE0F}";
+  $hash{"man_with_white_cane_facing_right"} = "\x{1F468}\x{200D}\x{1F9AF}\x{200D}\x{27A1}\x{FE0F}";
+  $hash{"person_in_manual_wheelchair_facing_right"} = "\x{1F9D1}\x{200D}\x{1F9BD}\x{200D}\x{27A1}\x{FE0F}";
+  $hash{"person_in_motorized_wheelchair_facing_right"} = "\x{1F9D1}\x{200D}\x{1F9BC}\x{200D}\x{27A1}\x{FE0F}";
+  $hash{"person_kneeling_facing_right"} = "\x{1F9CE}\x{200D}\x{27A1}\x{FE0F}";
+  $hash{"person_running_facing_right"} = "\x{1F3C3}\x{200D}\x{27A1}\x{FE0F}";
+  $hash{"person_walking_facing_right"} = "\x{1F6B6}\x{200D}\x{27A1}\x{FE0F}";
+  $hash{"person_with_white_cane_facing_right"} = "\x{1F9D1}\x{200D}\x{1F9AF}\x{200D}\x{27A1}\x{FE0F}";
+  $hash{"phoenix"} = "\x{1F426}\x{200D}\x{1F525}";
+  $hash{"root_vegetable"} = "\x{1FADC}";
+  $hash{"shovel"} = "\x{1FA8F}";
+  $hash{"splatter"} = "\x{1FADF}";
+  $hash{"woman_in_manual_wheelchair_facing_right"} = "\x{1F469}\x{200D}\x{1F9BD}\x{200D}\x{27A1}\x{FE0F}";
+  $hash{"woman_in_motorized_wheelchair_facing_right"} = "\x{1F469}\x{200D}\x{1F9BC}\x{200D}\x{27A1}\x{FE0F}";
+  $hash{"woman_kneeling_facing_right"} = "\x{1F9CE}\x{200D}\x{2640}\x{FE0F}\x{200D}\x{27A1}\x{FE0F}";
+  $hash{"woman_running_facing_right"} = "\x{1F3C3}\x{200D}\x{2640}\x{FE0F}\x{200D}\x{27A1}\x{FE0F}";
+  $hash{"woman_walking_facing_right"} = "\x{1F6B6}\x{200D}\x{2640}\x{FE0F}\x{200D}\x{27A1}\x{FE0F}";
+  $hash{"woman_with_white_cane_facing_right"} = "\x{1F469}\x{200D}\x{1F9AF}\x{200D}\x{27A1}\x{FE0F}";
+}
 if (! $ENV{SLACKEMOJI_STRICT}) {
   $hash{"face_exhaling"} = "\x{1F62E}\x{200D}\x{1F4A8}";
   $hash{"face_in_clouds"} = "\x{1F636}\x{200D}\x{1F32B}\x{FE0F}";
